@@ -1,13 +1,14 @@
 from __future__ import absolute_import, division, print_function
 
+import os
 from unittest import TestCase
 
-import pytest
 import numpy as np
+import pytest
 
+from larray.tests.common import assert_array_nan_equal, abspath
 from larray import Session, Axis, LArray, ndrange, isnan, larray_equal
-from larray.tests.test_la import assert_array_nan_equal, abspath
-from larray.utils import pickle
+from larray.util.misc import pickle
 
 try:
     import xlwings as xw
@@ -31,6 +32,7 @@ class TestSession(TestCase):
         self.c = 'c'
         self.d = {}
         self.e = ndrange([(2, 'a0'), (3, 'a1')])
+        self.e2 = ndrange(('a=a0..a2', 'b=b0..b2'))
         self.f = ndrange([(3, 'a0'), (2, 'a1')])
         self.g = ndrange([(2, 'a0'), (4, 'a1')])
         self.session = Session([
@@ -134,13 +136,19 @@ class TestSession(TestCase):
 
     def test_h5_io(self):
         fpath = abspath('test_session.h5')
-
         self.session.save(fpath)
+
         s = Session()
         s.load(fpath)
         # HDF does *not* keep ordering (ie, keys are always sorted)
         self.assertEqual(list(s.keys()), ['e', 'f', 'g'])
 
+        # update an array (overwrite=False)
+        Session(e=self.e2).save(fpath, overwrite=False)
+        s.load(fpath)
+        self.assertEqual(list(s.keys()), ['e', 'f', 'g'])
+        assert_array_nan_equal(s['e'], self.e2)
+
         s = Session()
         s.load(fpath, ['e', 'f'])
         self.assertEqual(list(s.keys()), ['e', 'f'])
@@ -148,10 +156,17 @@ class TestSession(TestCase):
     def test_xlsx_pandas_io(self):
         fpath = abspath('test_session.xlsx')
         self.session.save(fpath, engine='pandas_excel')
+
         s = Session()
         s.load(fpath, engine='pandas_excel')
         self.assertEqual(list(s.keys()), ['e', 'g', 'f'])
 
+        # update an array (overwrite=False)
+        Session(e=self.e2).save(fpath, engine='pandas_excel', overwrite=False)
+        s.load(fpath, engine='pandas_excel')
+        self.assertEqual(list(s.keys()), ['e', 'g', 'f'])
+        assert_array_nan_equal(s['e'], self.e2)
+
         fpath = abspath('test_session_ef.xlsx')
         self.session.save(fpath, ['e', 'f'], engine='pandas_excel')
         s = Session()
@@ -161,12 +176,20 @@ class TestSession(TestCase):
     @pytest.mark.skipif(xw is None, reason="xlwings is not available")
     def test_xlsx_xlwings_io(self):
         fpath = abspath('test_session_xw.xlsx')
+        # test save when Excel file does not exist
         self.session.save(fpath, engine='xlwings_excel')
+
         s = Session()
         s.load(fpath, engine='xlwings_excel')
         # ordering is only kept if the file did not exist previously (otherwise the ordering is left intact)
         self.assertEqual(list(s.keys()), ['e', 'g', 'f'])
 
+        # update an array (overwrite=False)
+        Session(e=self.e2).save(fpath, engine='xlwings_excel', overwrite=False)
+        s.load(fpath, engine='xlwings_excel')
+        self.assertEqual(list(s.keys()), ['e', 'g', 'f'])
+        assert_array_nan_equal(s['e'], self.e2)
+
         fpath = abspath('test_session_ef_xw.xlsx')
         self.session.save(fpath, ['e', 'f'], engine='xlwings_excel')
         s = Session()
@@ -184,12 +207,35 @@ class TestSession(TestCase):
 
     def test_pickle_io(self):
         fpath = abspath('test_session.pkl')
-
         self.session.save(fpath)
+
         s = Session()
         s.load(fpath, engine='pickle')
         self.assertEqual(list(s.keys()), ['e', 'g', 'f'])
 
+        # update an array (overwrite=False)
+        Session(e=self.e2).save(fpath, overwrite=False)
+        s.load(fpath, engine='pickle')
+        self.assertEqual(list(s.keys()), ['e', 'g', 'f'])
+        assert_array_nan_equal(s['e'], self.e2)
+
+    def test_to_globals(self):
+        with pytest.warns(RuntimeWarning) as caught_warnings:
+            self.session.to_globals()
+        assert len(caught_warnings) == 1
+        assert caught_warnings[0].message.args[0] == "Session.to_globals should usually only be used in interactive " \
+                                                     "consoles and not in scripts. Use warn=False to deactivate this " \
+                                                     "warning."
+        assert caught_warnings[0].filename == __file__
+
+        self.assertIs(a, self.a)
+        self.assertIs(b, self.b)
+        self.assertIs(c, self.c)
+        self.assertIs(d, self.d)
+        self.assertIs(e, self.e)
+        self.assertIs(f, self.f)
+        self.assertIs(g, self.g)
+
     def test_eq(self):
         sess = self.session.filter(kind=LArray)
         expected = Session([('e', self.e), ('f', self.f), ('g', self.g)])
@@ -270,8 +316,4 @@ class TestSession(TestCase):
 
 
 if __name__ == "__main__":
-    # import doctest
-    # import unittest
-    # doctest.testmod(larray.core)
-    # unittest.main()
     pytest.main()
